
Python utilities for Virtual Reality and Clinical Gait Analysis Laboratory, High Point University.


Please include these citations
---------------------

> Duarte, M. (2015) Notes on Scientific Computing for Biomechanics and Motor Control. GitHub repository, https://github.com/demotu/BMC.


> Long, B., Gosselin, D. (2017) Python utilities for Virtual Reality and Clinical Gait Analysis. GitHub repository, https://github.com/vrcgal/vrcgal_py.
